@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-01-13'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2015-03-03'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -112,9 +112,10 @@ Will sort the resulting completion list, so you don't have to presort the array.
 
 _
     args => {
-        word  => { schema=>[str=>{default=>''}], pos=>0, req=>1 },
-        array => { schema=>['array*'=>{of=>'str*'}], req=>1 },
-        ci    => { schema=>['bool'] },
+        word    => { schema=>[str=>{default=>''}], pos=>0, req=>1 },
+        array   => { schema=>['array*'=>{of=>'str*'}], req=>1 },
+        ci      => { schema=>['bool'] },
+        exclude => { schema=>['array*'] },
     },
     result_naked => 1,
     result => {
@@ -122,15 +123,29 @@ _
     },
 };
 sub complete_array_elem {
+    use experimental 'smartmatch';
+
     my %args  = @_;
     my $array = $args{array} or die "Please specify array";
     my $word  = $args{word} // "";
     my $ci    = $args{ci} // $Complete::OPT_CI;
 
+    my $has_exclude = $args{exclude};
+    my $exclude;
+    if ($ci) {
+        $exclude = [map {uc} @{ $args{exclude} // [] }];
+    } else {
+        $exclude = $args{exclude} // [];
+    }
+
     my $wordu = uc($word);
     my @words;
     for (@$array) {
-        next unless 0==($ci ? index(uc($_), $wordu) : index($_, $word));
+        my $uc = uc($_) if $ci;
+        next unless 0==($ci ? index($uc, $wordu) : index($_, $word));
+        if ($has_exclude) {
+            next if ($ci ? $uc : $_) ~~ @$exclude;
+        }
         push @words, $_;
     }
     $ci ? [sort {lc($a) cmp lc($b)} @words] : [sort @words];
@@ -461,7 +476,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.22 of Complete::Util (from Perl distribution Complete-Util), released on 2015-01-13.
+This document describes version 0.23 of Complete::Util (from Perl distribution Complete-Util), released on 2015-03-03.
 
 =head1 DESCRIPTION
 
@@ -530,6 +545,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ci> => I<bool>
 
+=item * B<exclude> => I<array>
+
 =item * B<word>* => I<str> (default: "")
 
 =back
@@ -678,7 +695,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Complete-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Util>.
 
 =head1 BUGS
 
